<?php
/**
* Post meta, navigations, site titles functions
*
* @package CleanWP WordPress Theme
* @copyright Copyright (C) 2018 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

if ( ! function_exists( 'cleanwp_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function cleanwp_posted_on() {
    $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
    if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
        $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
    }

    $time_string = sprintf( $time_string,
        esc_attr( get_the_date( 'c' ) ),
        esc_html( get_the_date() ),
        esc_attr( get_the_modified_date( 'c' ) ),
        esc_html( get_the_modified_date() )
    );

    $posted_on = sprintf(
        /* translators: %s: post date. */ _x( '<i class="fa fa-calendar" aria-hidden="true"></i> Posted on %s', 'post date', 'cleanwp' ),
        '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>&nbsp;&nbsp;'
    );

    $byline = sprintf(
        /* translators: %s: post author. */ _x( '<i class="fa fa-user" aria-hidden="true"></i> by %s', 'post author', 'cleanwp' ),
        '<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
    );

    echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.
}
endif;

if ( ! function_exists( 'cleanwp_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function cleanwp_entry_footer() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space after the comma */
        $categories_list = get_the_category_list( esc_html__( ', ', 'cleanwp' ) );
        if ( $categories_list ) {
            /* translators: 1: list of categories. */ printf( '<span class="cat-links">' . __( '<i class="fa fa-folder-open" aria-hidden="true"></i> Posted in %1$s', 'cleanwp' ) . '&nbsp;&nbsp;&nbsp;</span>', $categories_list ); // WPCS: XSS OK.
        }
        /* translators: used between list items, there is a space after the comma */
        $tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'cleanwp' ) );
        if ( $tags_list ) {
            /* translators: 1: list of tags. */ printf( '<span class="tags-links">' . __( '<i class="fa fa-tags" aria-hidden="true"></i> Tagged %1$s', 'cleanwp' ) . '&nbsp;&nbsp;&nbsp;</span>', $tags_list ); // WPCS: XSS OK.
        }
    }
    if ( comments_open() ) {
        echo '<span class="comments-link"><i class="fa fa-comments" aria-hidden="true"></i> ';
        comments_popup_link( esc_html__( 'Leave a comment', 'cleanwp' ), esc_html__( '1 Comment', 'cleanwp' ), esc_html__( '% Comments', 'cleanwp' ) );
        echo '&nbsp;&nbsp;&nbsp;</span>';
    }
    edit_post_link( esc_html__( 'Edit', 'cleanwp' ), '<span class="edit-link"><i class="fa fa-pencil" aria-hidden="true"></i> ', '</span>' );
}
endif;